@@ -14,20 +14,25 @@ pub enum ClientType {
 }
 
 impl ClientType {
+    const TENDERMINT_STR: &'static str = "07-tendermint";
+
+    #[cfg_attr(not(test), allow(dead_code))]
+    const MOCK_STR: &'static str = "9999-mock";
+
     /// Yields the identifier of this client type as a string
-    pub fn as_string(&self) -> &'static str {
+    pub fn as_str(&self) -> &'static str {
         match self {
-            Self::Tendermint => "07-tendermint",
+            Self::Tendermint => Self::TENDERMINT_STR,
 
             #[cfg(any(test, feature = "mocks"))]
-            Self::Mock => "9999-mock",
+            Self::Mock => Self::MOCK_STR,
         }
     }
 }
 
 impl fmt::Display for ClientType {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "ClientType({})", self.as_string())
+        write!(f, "ClientType({})", self.as_str())
     }
 }
 
@@ -36,10 +41,10 @@ impl std::str::FromStr for ClientType {
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         match s {
-            "07-tendermint" => Ok(Self::Tendermint),
+            Self::TENDERMINT_STR => Ok(Self::Tendermint),
 
             #[cfg(any(test, feature = "mocks"))]
-            "mock" => Ok(Self::Mock),
+            Self::MOCK_STR => Ok(Self::Mock),
 
             _ => Err(error::Kind::UnknownClientType(s.to_string()).into()),
         }
@@ -65,7 +70,7 @@ mod tests {
 
     #[test]
     fn parse_mock_client_type() {
-        let client_type = ClientType::from_str("mock");
+        let client_type = ClientType::from_str("9999-mock");
 
         match client_type {
             Ok(ClientType::Mock) => (),
@@ -85,4 +90,20 @@ mod tests {
             _ => panic!("parse didn't fail"),
         }
     }
+
+    #[test]
+    fn parse_mock_as_string_result() {
+        let client_type = ClientType::Mock;
+        let type_string = client_type.as_str();
+        let client_type_from_str = ClientType::from_str(type_string).unwrap();
+        assert_eq!(client_type_from_str, client_type);
+    }
+
+    #[test]
+    fn parse_tendermint_as_string_result() {
+        let client_type = ClientType::Tendermint;
+        let type_string = client_type.as_str();
+        let client_type_from_str = ClientType::from_str(type_string).unwrap();
+        assert_eq!(client_type_from_str, client_type);
+    }
 }
