@@ -166,8 +166,8 @@ impl Attributes {
     pub fn port_id(&self) -> &PortId {
         &self.port_id
     }
-    pub fn channel_id(&self) -> &Option<ChannelId> {
-        &self.channel_id
+    pub fn channel_id(&self) -> Option<&ChannelId> {
+        self.channel_id.as_ref()
     }
 }
 
@@ -188,8 +188,14 @@ impl Default for Attributes {
 pub struct OpenInit(Attributes);
 
 impl OpenInit {
-    pub fn channel_id(&self) -> &Option<ChannelId> {
-        &self.0.channel_id
+    pub fn attributes(&self) -> &Attributes {
+        &self.0
+    }
+    pub fn channel_id(&self) -> Option<&ChannelId> {
+        self.0.channel_id.as_ref()
+    }
+    pub fn port_id(&self) -> &PortId {
+        &self.0.port_id
     }
     pub fn height(&self) -> Height {
         self.0.height
@@ -232,8 +238,14 @@ impl From<OpenInit> for IbcEvent {
 pub struct OpenTry(Attributes);
 
 impl OpenTry {
-    pub fn channel_id(&self) -> &Option<ChannelId> {
-        &self.0.channel_id
+    pub fn attributes(&self) -> &Attributes {
+        &self.0
+    }
+    pub fn channel_id(&self) -> Option<&ChannelId> {
+        self.0.channel_id.as_ref()
+    }
+    pub fn port_id(&self) -> &PortId {
+        &self.0.port_id
     }
     pub fn height(&self) -> Height {
         self.0.height
@@ -279,8 +291,11 @@ impl OpenAck {
     pub fn attributes(&self) -> &Attributes {
         &self.0
     }
-    pub fn channel_id(&self) -> &Option<ChannelId> {
-        &self.0.channel_id
+    pub fn channel_id(&self) -> Option<&ChannelId> {
+        self.0.channel_id.as_ref()
+    }
+    pub fn port_id(&self) -> &PortId {
+        &self.0.port_id
     }
     pub fn height(&self) -> Height {
         self.0.height
@@ -288,6 +303,10 @@ impl OpenAck {
     pub fn set_height(&mut self, height: Height) {
         self.0.height = height;
     }
+
+    pub fn counterparty_channel_id(&self) -> Option<&ChannelId> {
+        self.0.counterparty_channel_id.as_ref()
+    }
 }
 
 impl From<Attributes> for OpenAck {
@@ -326,8 +345,11 @@ impl OpenConfirm {
     pub fn attributes(&self) -> &Attributes {
         &self.0
     }
-    pub fn channel_id(&self) -> &Option<ChannelId> {
-        &self.0.channel_id
+    pub fn channel_id(&self) -> Option<&ChannelId> {
+        self.0.channel_id.as_ref()
+    }
+    pub fn port_id(&self) -> &PortId {
+        &self.0.port_id
     }
     pub fn height(&self) -> Height {
         self.0.height
@@ -444,8 +466,8 @@ impl std::fmt::Display for CloseInit {
 pub struct CloseConfirm(Attributes);
 
 impl CloseConfirm {
-    pub fn channel_id(&self) -> &Option<ChannelId> {
-        &self.0.channel_id
+    pub fn channel_id(&self) -> Option<&ChannelId> {
+        self.0.channel_id.as_ref()
     }
     pub fn height(&self) -> Height {
         self.0.height
@@ -523,6 +545,18 @@ impl SendPacket {
     pub fn set_height(&mut self, height: Height) {
         self.height = height;
     }
+    pub fn src_port_id(&self) -> &PortId {
+        &self.packet.source_port
+    }
+    pub fn src_channel_id(&self) -> &ChannelId {
+        &self.packet.source_channel
+    }
+    pub fn dst_port_id(&self) -> &PortId {
+        &self.packet.destination_port
+    }
+    pub fn dst_channel_id(&self) -> &ChannelId {
+        &self.packet.destination_channel
+    }
 }
 
 impl TryFrom<RawObject> for SendPacket {
@@ -544,7 +578,7 @@ impl From<SendPacket> for IbcEvent {
 
 impl std::fmt::Display for SendPacket {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> Result<(), std::fmt::Error> {
-        write!(f, "h:{}, {}", self.height, self.packet)
+        write!(f, "SendPacket - h:{}, {}", self.height, self.packet)
     }
 }
 
@@ -561,6 +595,18 @@ impl ReceivePacket {
     pub fn set_height(&mut self, height: Height) {
         self.height = height;
     }
+    pub fn src_port_id(&self) -> &PortId {
+        &self.packet.source_port
+    }
+    pub fn src_channel_id(&self) -> &ChannelId {
+        &self.packet.source_channel
+    }
+    pub fn dst_port_id(&self) -> &PortId {
+        &self.packet.destination_port
+    }
+    pub fn dst_channel_id(&self) -> &ChannelId {
+        &self.packet.destination_channel
+    }
 }
 
 impl TryFrom<RawObject> for ReceivePacket {
@@ -582,7 +628,7 @@ impl From<ReceivePacket> for IbcEvent {
 
 impl std::fmt::Display for ReceivePacket {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> Result<(), std::fmt::Error> {
-        write!(f, "h:{}, {}", self.height, self.packet)
+        write!(f, "ReceivePacket - h:{}, {}", self.height, self.packet)
     }
 }
 
@@ -601,6 +647,18 @@ impl WriteAcknowledgement {
     pub fn set_height(&mut self, height: Height) {
         self.height = height;
     }
+    pub fn src_port_id(&self) -> &PortId {
+        &self.packet.source_port
+    }
+    pub fn src_channel_id(&self) -> &ChannelId {
+        &self.packet.source_channel
+    }
+    pub fn dst_port_id(&self) -> &PortId {
+        &self.packet.destination_port
+    }
+    pub fn dst_channel_id(&self) -> &ChannelId {
+        &self.packet.destination_channel
+    }
 }
 
 impl TryFrom<RawObject> for WriteAcknowledgement {
@@ -627,7 +685,11 @@ impl From<WriteAcknowledgement> for IbcEvent {
 
 impl std::fmt::Display for WriteAcknowledgement {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> Result<(), std::fmt::Error> {
-        write!(f, "h:{}, {}", self.height, self.packet)
+        write!(
+            f,
+            "WriteAcknowledgement - h:{}, {}",
+            self.height, self.packet
+        )
     }
 }
 
@@ -644,6 +706,12 @@ impl AcknowledgePacket {
     pub fn set_height(&mut self, height: Height) {
         self.height = height;
     }
+    pub fn src_port_id(&self) -> &PortId {
+        &self.packet.source_port
+    }
+    pub fn src_channel_id(&self) -> &ChannelId {
+        &self.packet.source_channel
+    }
 }
 
 impl TryFrom<RawObject> for AcknowledgePacket {
@@ -678,7 +746,7 @@ impl TimeoutPacket {
         self.height
     }
     pub fn set_height(&mut self, height: Height) {
-        self.height = height
+        self.height = height;
     }
     pub fn src_port_id(&self) -> &PortId {
         &self.packet.source_port
@@ -686,6 +754,12 @@ impl TimeoutPacket {
     pub fn src_channel_id(&self) -> &ChannelId {
         &self.packet.source_channel
     }
+    pub fn dst_port_id(&self) -> &PortId {
+        &self.packet.destination_port
+    }
+    pub fn dst_channel_id(&self) -> &ChannelId {
+        &self.packet.destination_channel
+    }
 }
 
 impl TryFrom<RawObject> for TimeoutPacket {
@@ -706,7 +780,7 @@ impl From<TimeoutPacket> for IbcEvent {
 
 impl std::fmt::Display for TimeoutPacket {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> Result<(), std::fmt::Error> {
-        write!(f, "h:{}, {}", self.height, self.packet)
+        write!(f, "TimeoutPacket - h:{}, {}", self.height, self.packet)
     }
 }
 
@@ -723,6 +797,18 @@ impl TimeoutOnClosePacket {
     pub fn set_height(&mut self, height: Height) {
         self.height = height;
     }
+    pub fn src_port_id(&self) -> &PortId {
+        &self.packet.source_port
+    }
+    pub fn src_channel_id(&self) -> &ChannelId {
+        &self.packet.source_channel
+    }
+    pub fn dst_port_id(&self) -> &PortId {
+        &self.packet.destination_port
+    }
+    pub fn dst_channel_id(&self) -> &ChannelId {
+        &self.packet.destination_channel
+    }
 }
 
 impl TryFrom<RawObject> for TimeoutOnClosePacket {
@@ -743,6 +829,10 @@ impl From<TimeoutOnClosePacket> for IbcEvent {
 
 impl std::fmt::Display for TimeoutOnClosePacket {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> Result<(), std::fmt::Error> {
-        write!(f, "h:{}, {}", self.height, self.packet)
+        write!(
+            f,
+            "TimeoutOnClosePacket - h:{}, {}",
+            self.height, self.packet
+        )
     }
 }
