@@ -168,10 +168,10 @@ impl ClientId {
     /// chain, for example, will have the prefix '07-tendermint'.
     pub fn prefix(client_type: ClientType) -> &'static str {
         match client_type {
-            ClientType::Tendermint => ClientType::Tendermint.as_string(),
+            ClientType::Tendermint => ClientType::Tendermint.as_str(),
 
             #[cfg(any(test, feature = "mocks"))]
-            ClientType::Mock => ClientType::Mock.as_string(),
+            ClientType::Mock => ClientType::Mock.as_str(),
         }
     }
 
